//
//  ContentMainIntroduceCreatorAllViewModel.swift
//  SodaLive
//
//  Created by klaus on 2/22/25.
//

import Foundation
import Combine

final class ContentMainIntroduceCreatorAllViewModel: ObservableObject {
    private let repository = ContentMainTabFreeRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var introduceCreatorList: [GetAudioContentMainItem] = []
    
    var page = 1
    var isLast = false
    private let size = 20
    
    func getIntroduceCreatorList() {
        if (!isLast && !isLoading) {
            isLoading = true
            repository.getIntroduceCreatorList(page: page, size: size)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    self.isLoading = false
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<[GetAudioContentMainItem]>.self, from: responseData)
                        self.isLoading = false
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                introduceCreatorList.removeAll()
                            }
                            
                            if !data.isEmpty {
                                page += 1
                                self.introduceCreatorList.append(contentsOf: data)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                        self.isLoading = false
                    }
                }
                .store(in: &subscription)
        }
    }
}
