//
//  UserProfileFanTalkViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/11.
//

import Foundation
import Combine

final class UserProfileFanTalkViewModel: ObservableObject {
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var cheersTotalCount = 0
    @Published var cheersList = [GetCheersResponseItem]()
    
    @Published var reportCheersId = 0
    @Published var isShowCheersReportView = false
    @Published var isShowCheersDeleteView = false
    
    var errorPopup: ((String) -> Void)?
    var setLoading: ((Bool) -> Void)?
    
    private var repository = ExplorerRepository()
    private let reportRepository = ReportRepository()
    private var subscription = Set<AnyCancellable>()
    
    var cheersPage = 1
    var pageSize = 10
    
    private var isCheersLast = false
    
    func getCheersList(creatorId: Int) {
        if !isCheersLast && !isLoading {
            if let setLoading = self.setLoading {
                setLoading(true)
            }
            isLoading = true
            
            repository.getCreatorProfileCheers(userId: creatorId, page: cheersPage, size: pageSize)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    if let setLoading = self.setLoading {
                        setLoading(false)
                    }
                    self.isLoading = false
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetCheersResponse>.self, from: responseData)
                        
                        if let data = decoded.data, decoded.success {
                            if !data.cheers.isEmpty {
                                cheersPage += 1
                                self.cheersTotalCount = data.totalCount
                                self.cheersList.append(contentsOf: data.cheers)
                            } else {
                                isCheersLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            if let errorPopup = errorPopup {
                                errorPopup(self.errorMessage)
                            } else {
                                self.isShowPopup = true
                            }
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        if let errorPopup = errorPopup {
                            errorPopup(self.errorMessage)
                        } else {
                            self.isShowPopup = true
                        }
                    }
                }
                .store(in: &subscription)
        }
    }
    
    func writeCheersReply(parentCheersId: Int, creatorId: Int, cheersReplyContent: String) {
        if cheersReplyContent.trimmingCharacters(in: .whitespaces).isEmpty {
            if let errorPopup = errorPopup {
                errorPopup("내용을 입력하세요")
            } else {
                errorMessage = "내용을 입력하세요"
                isShowPopup = true
            }
            
            return
        }
        
        if let setLoading = self.setLoading {
            setLoading(true)
        }
        isLoading = true
        
        repository.writeCheers(parentCheersId: parentCheersId, creatorId: creatorId, content: cheersReplyContent)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                if let setLoading = self.setLoading {
                    setLoading(false)
                }
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        cheersPage = 1
                        isCheersLast = false
                        cheersList.removeAll()
                        self.getCheersList(creatorId: creatorId)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        if let errorPopup = errorPopup {
                            errorPopup(self.errorMessage)
                        } else {
                            self.isShowPopup = true
                        }
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    if let errorPopup = errorPopup {
                        errorPopup(self.errorMessage)
                    } else {
                        self.isShowPopup = true
                    }
                }
            }
            .store(in: &subscription)
    }
    
    func writeCheers(creatorId: Int, cheersContent: String) {
        if cheersContent.trimmingCharacters(in: .whitespaces).isEmpty {
            if let errorPopup = errorPopup {
                errorPopup("내용을 입력하세요")
            } else {
                errorMessage = "내용을 입력하세요"
                isShowPopup = true
            }
            
            return
        }
        
        if let setLoading = self.setLoading {
            setLoading(true)
        }
        isLoading = true
        
        repository.writeCheers(parentCheersId: nil, creatorId: creatorId, content: cheersContent)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                if let setLoading = self.setLoading {
                    setLoading(false)
                }
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        cheersPage = 1
                        isCheersLast = false
                        cheersList.removeAll()
                        self.getCheersList(creatorId: creatorId)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        if let errorPopup = errorPopup {
                            errorPopup(self.errorMessage)
                        } else {
                            self.isShowPopup = true
                        }
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    if let errorPopup = errorPopup {
                        errorPopup(self.errorMessage)
                    } else {
                        self.isShowPopup = true
                    }
                }
            }
            .store(in: &subscription)
    }
    
    func modifyCheers(cheersId: Int, creatorId: Int, cheersContent: String? = nil, isActive: Bool? = nil) {
        if cheersContent == nil && isActive == nil {
            if let errorPopup = errorPopup {
                errorPopup("변경사항이 없습니다.")
            } else {
                errorMessage = "변경사항이 없습니다."
                isShowPopup = true
            }
        }
        
        if let cheersContent = cheersContent, cheersContent.trimmingCharacters(in: .whitespaces).isEmpty {
            if let errorPopup = errorPopup {
                errorPopup("내용을 입력하세요")
            } else {
                errorMessage = "내용을 입력하세요"
                isShowPopup = true
            }
            
            return
        }
        
        if let setLoading = self.setLoading {
            setLoading(true)
        }
        isLoading = true
        
        repository.modifyCheers(cheersId: cheersId, content: cheersContent, isActive: isActive)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                if let setLoading = self.setLoading {
                    setLoading(false)
                }
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        cheersPage = 1
                        isCheersLast = false
                        cheersList.removeAll()
                        self.getCheersList(creatorId: creatorId)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
    
    func report(type: ReportType, reason: String = "프로필 신고") {
        isLoading = true
        
        let request = ReportRequest(type: type, reason: reason, reportedMemberId: nil, cheersId: reportCheersId > 0 && type == .CHEERS ? reportCheersId : nil, audioContentId: nil)
        reportRepository.report(request: request)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                self.reportCheersId = 0
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if let message = decoded.message {
                        self.errorMessage = message
                    } else {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    }
                    
                    self.isShowPopup = true
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
